@@ -1,6 +1,8 @@
 from airtouch4pyapi import packetmap
 import libscrc
 import socket
+import errno
+from socket import error as socket_error
 
 def MessageObjectToMessagePacket(messageObject, mapName):
     messageString = "80b001";
@@ -61,8 +63,13 @@ def SendMessagePacketToAirtouch(messageString, ipAddress):
     TCP_PORT = 9004
     BUFFER_SIZE = 4096
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    s.connect((ipAddress, TCP_PORT))
-    s.send(bytearray.fromhex(messageString))
-    data = s.recv(BUFFER_SIZE)
-    s.close()
+    s.settimeout(15)
+    data = ""
+    try:
+        s.connect((ipAddress, TCP_PORT))
+        s.send(bytearray.fromhex(messageString))
+        data = s.recv(BUFFER_SIZE)
+        s.close()
+    except socket_error as serr:
+        data = serr;
     return data;
\ No newline at end of file
